//
// QPerforce is a gui interface to the perforce revision control
// system. It is based on the qt library, and should be easily portable
// across any platform that has this toolkit available.
// 
// Copyright (C) 2002 Jacob Gladish
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
#ifndef __P4_PROCESS_H__
#define __P4_PROCESS_H__

#include "BranchSpec.h"
#include "Job.h"
#include "SubmittedChangeList.h"
#include "User.h"

#include <qstring.h>
#include <qstringlist.h>


// if this ever moves to qt 3.x, then this class should inherit 
// QProcess.
class P4Process  
{

public:

	P4Process();
	virtual ~P4Process();  

  const Perforce::UserList                getUsers();
  const Perforce::SubmittedChangeListList getSubmittedChangeLists();
  const Perforce::BranchSpecList          getBranchSpecs();
  const Perforce::JobList                 getJobs();

  void exec( const QString& args, bool forceSupressOutput = false );

  inline const QStringList& getCommandStdOutput() const;

private:  

  QStringList _cmdStdOutput;

#ifdef WIN32
  void _win32Exec( const QString& args );
#endif

};


inline const QStringList& P4Process::getCommandStdOutput() const
{
  return _cmdStdOutput;
}


#endif 

